@@ -39,11 +39,11 @@
  * 3.1.2b1 would be 0x03010201.  Snapshot from Jan 2, 2003 would be
  * 0xFF030102.
  * See TSK_VERSION_STR for string form. */
-#define TSK_VERSION_NUM 0x040600ff
+#define TSK_VERSION_NUM 0x040800ff
 
 /** Version of code in string form. See TSK_VERSION_NUM for
  * integer form. */
-#define TSK_VERSION_STR "4.6.0"
+#define TSK_VERSION_STR "4.8.0"
 
 
 /* include the TSK-specific header file that we created in autoconf
@@ -247,32 +247,26 @@ extern "C" {
     typedef uint64_t TSK_INUM_T;        ///< Data type used to internally store metadata / inode addresses
 #define PRIuINUM	PRIu64
 #define PRIxINUM	PRIx64
-#define PRIdINUM	PRId64
 
     typedef uint32_t TSK_UID_T; ///< Data type used to internally store User IDs
 #define PRIuUID	    PRIu32
 #define PRIxUID	    PRIx32
-#define PRIdUID	    PRId32
 
     typedef uint32_t TSK_GID_T; ///< Data type used to internally store Group IDs
 #define PRIuGID	    PRIu32
 #define PRIxGID	    PRIx32
-#define PRIdGID	    PRId32
 
     typedef uint64_t TSK_DADDR_T;       ///< Data type used to internally store sector and block addresses
 #define PRIuDADDR   PRIu64
 #define PRIxDADDR   PRIx64
-#define PRIdDADDR   PRId64
 
     typedef int64_t TSK_OFF_T;  ///< Data type used to internally store volume, file, etc. sizes and offsets
-#define PRIuOFF		PRIu64
 #define PRIxOFF		PRIx64
 #define PRIdOFF		PRId64
 
     typedef uint32_t TSK_PNUM_T;        ///< Data type used to internally store partition addresses
 #define PRIuPNUM	PRIu32
 #define PRIxPNUM	PRIx32
-#define PRIdPNUM	PRId32
 //@}
 
 
@@ -288,7 +282,7 @@ extern "C" {
     typedef enum {
         TSK_WALK_CONT = 0x0,    ///< Walk function should continue to next object
         TSK_WALK_STOP = 0x1,    ///< Walk function should stop processing units and return OK
-        TSK_WALK_ERROR = 0x2,   ///< Walk function should stop processing units and return error
+        TSK_WALK_ERROR = 0x2   ///< Walk function should stop processing units and return error
     } TSK_WALK_RET_ENUM;
 
 
@@ -303,6 +297,7 @@ extern "C" {
 #define TSK_ERR_FS	0x08000000
 #define TSK_ERR_HDB	0x10000000
 #define TSK_ERR_AUTO 0x20000000
+#define TSK_ERR_POOL 0x40000000
 #define TSK_ERR_MASK	0x00ffffff
 
 #define TSK_ERR_AUX_MALLOC	(TSK_ERR_AUX | 0)
@@ -335,6 +330,12 @@ extern "C" {
 #define TSK_ERR_VS_ARG	    (TSK_ERR_VS | 7)
 #define TSK_ERR_VS_MAX		8
 
+#define TSK_ERR_POOL_UNKTYPE    (TSK_ERR_POOL | 0)
+#define TSK_ERR_POOL_UNSUPTYPE  (TSK_ERR_IMG | 1)
+#define TSK_ERR_POOL_ARG        (TSK_ERR_POOL | 2)
+#define TSK_ERR_POOL_GENPOOL    (TSK_ERR_POOL | 3)
+#define TSK_ERR_POOL_MAX        4
+
 #define TSK_ERR_FS_UNKTYPE	(TSK_ERR_FS | 0)
 #define TSK_ERR_FS_UNSUPTYPE	(TSK_ERR_FS | 1)
 #define TSK_ERR_FS_UNSUPFUNC		(TSK_ERR_FS | 2)
